# PowerShell

To use this language, use the class "language-powershell".

## Comments

    # This is a comment
    <# This is a
    multi-line comment #>

## Variable Interpolation

    $Name = "Alice"
    Write-Host "Hello, my name is $Name."

## Full Example

    Function SayHello([string]$name) {
        Write-Host "Hello, $name."
    }
    $Names = @("Bob", "Alice")

    $Names | ForEach {
        SayHello $_
    }